| rstudio.prefs-package | R Documentation |
Provides an interface for working with 'RStudio' preference files to modify settings and addin shortcuts without using point-and-click option menus. Useful for ensuring a unified experience across devices and for enforcing best practices. Also exposes some settings not available in the Global Options dialog.
Maintainer: S.A. van der Wulp vdwulp@gmail.com [copyright holder]
Authors:
S.A. van der Wulp vdwulp@gmail.com [copyright holder]
Daniel D. Sjoberg danield.sjoberg@gmail.com (ORCID) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.