Set RStudio Keyboard Shortcuts
Source:R/use_rstudio_keyboard_shortcut.R
use_rstudio_keyboard_shortcut.RdThis function updates the RStudio keyboard shortcuts saved in
the addins.json file.
Arguments
- ...
series of RStudio keyboard shortcuts to update. The argument name is the keyboard shortcut, and the value is a string of the function name that will execute, or
NULLto remove the shortcut. If a new shortcut shares a key or function with an existing one, the previous binding is removed.- .write_json
logical indicating whether to update and overwrite the existing JSON file of options. Default is
TRUE. WhenFALSE, the function will return a list of all shortcuts, instead of writing them to file.- .backup
logical indicating whether to create a back-up of shortcuts file before it's updated. Default is
TRUE.