Set RStudio Secondary Repository
Source:R/use_rstudio_secondary_repo.R
use_rstudio_secondary_repo.RdThis function updates the RStudio preferences saved in
the rstudio-prefs.json file to include the secondary repositories
passed by the user. If a new name for an existing repository is
passed by the user, the name will be updated in the JSON file.
Value
Invisibly returns the updated cran_mirror preference as a named
list on success, or NULL if no updates were made (no changes, user
aborted, or not in an interactive session).